@@ -22,9 +22,10 @@
 
 """
 
-from rains.baseic.environment.make import create_runtime_environment
+__version__ = '0.3.7'
 
-
-# 创建项目环境
-# 一般情况下, 无论是通过 rains命令行工具 还是 Python脚本 执行，都会在工作路径中创建项目环境。
-create_runtime_environment()
+__name__ = 'rains'
+__author__ = 'cat7'
+__email__ = 'quinn.7@foxmail.com'
+__description__ = '这是一个开箱即用、稳定且高效的工程化全栈自动化测试框架。'
+__url__ = 'https://gitee.com/catcat7/rains'
