@@ -30,6 +30,14 @@ def singleton_pattern(cls):
 
     * 用于装饰类, 被装饰的类在全局引用时只会创建一个实例.
 
+    ---
+    示例:
+        >>> @singleton_pattern
+        >>> class T(object): ...
+        >>> t1 = T()
+        >>> t2 = T()
+        >>> id(t1) == id(t2) :: True
+
     """
 
     instances = {}
