@@ -38,7 +38,7 @@ class WebPlantView(object):
     """
     [ Web视图 ]
 
-    * 提供针对浏览器本身的操作函数.
+    * 封装了浏览器本身的功能, 如获取浏览器信息、弹窗控制、标签页控制等.
 
     """
 
@@ -46,17 +46,17 @@ class WebPlantView(object):
     """ [ 引擎对象 ] """
 
     # ------------------------------
-    def __init__(self, driver: Any):
+    def __init__(self, web_driver: Any):
         """
         [ Web视图 ]
 
         ---
         参数:
-            driver { WebEngine } : Web引擎对象.
+            web_driver { WebEngine } : Web引擎对象.
 
         """
 
-        self._web_driver = driver
+        self._web_driver = web_driver
 
     # ------------------------------
     @property
@@ -190,13 +190,13 @@ class _WebPlantViewMapGet(_WebPlantViewMapBase):
             raise WebPlantViewFunctionRunError(self._driver_id, message, error)
 
     # ------------------------------
-    def window_list(self) -> Any:
+    def window_list(self) -> list:
         """
         [ 获取标签页句柄列表 ]
 
         ---
         返回:
-            Any : 标签页句柄列表.
+            list : 标签页句柄列表.
 
         """
 
@@ -217,7 +217,7 @@ class _WebPlantViewMapGet(_WebPlantViewMapBase):
 
         ---
         返回:
-            Any : 当前标签页句柄.
+            Any : 当前标签页句柄对象.
 
         """
 
