@@ -73,28 +73,28 @@ class TaskTest(WebTask):
         
         print('set_task_init')
 
-        self.user_input = self.plant.element(
+        self.user_input = self._plant.element(
             page='超管后台', 
             name='邮箱输入框', 
             by_key=BY.XPATH, 
             by_value='/html/body/div/div/div/div/div[2]/form/div[1]/div/input'
         )
 
-        self.password_input = self.plant.element(
+        self.password_input = self._plant.element(
             page='超管后台', 
             name='密码输入框', 
             by_key=BY.XPATH, 
             by_value='/html/body/div/div/div/div/div[2]/form/div[2]/div/input'
         )
 
-        self.login_button = self.plant.element(
+        self.login_button = self._plant.element(
             page='超管后台', 
             name='Login按钮', 
             by_key=BY.XPATH, 
             by_value='/html/body/div/div/div/div/div[2]/form/div[4]/div/button'
         )
 
-        self.create_button = self.plant.element(
+        self.create_button = self._plant.element(
             page='超管后台', 
             name='Login按钮', 
             by_key=BY.XPATH, 
@@ -102,12 +102,12 @@ class TaskTest(WebTask):
         )
 
     def set_task_quit(self):
-        self.plant.view.get.url()
+        self._plant.view.get.url()
         print('set_task_quit')
 
     def set_case_init(self):
         print('set_case_init')
-        self.plant.view.page.goto('http://manage.dev-tea.cblink.net/')
+        self._plant.view.page.goto('http://manage.dev-tea.cblink.net/')
 
     def set_case_quit(self):
         print('set_case_quit')
@@ -116,7 +116,7 @@ class TaskTest(WebTask):
         """
         登录成功
         """
-        self.plant.view.get.url()
+        self._plant.view.get.url()
         self.user_input.input.send('admin@baocai.us')
         self.password_input.input.send('123456')
         self.login_button.mouse.tap()
